SizeBounded

Trait SizeBounded 

pub trait SizeBounded {
    // Required method
    fn size(&self) -> u64;
}
A resource with a queryable byte size or capacity.

Required Methods

fn size(&self) -> u64

The size or capacity of the resource in bytes.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors