Module spin_lock

Module spin_lock 

Spin lock for critical sections short enough that parking costs more than spinning.

Structs

SpinLock
A spin lock for very short critical sections with TBB-inspired exponential backoff.
SpinLockGuard
Guard for SpinLock that automatically unlocks on drop.